<?php
$lang['address'] = 'Adresse';
$lang['add_category'] = 'Legg til kategori';
$lang['add_icon'] = 'Legg til ikon';
$lang['add_map'] = 'Legg til kart';
$lang['add_map_point'] = 'Legg til kart punkt';
$lang['add_point_for_map'] = 'Legg punkt til kart &quot;%s&quot;';
$lang['aerial'] = 'Flyfoto';
$lang['anchor_x'] = 'Anker X pixel lokasjon';
$lang['anchor_y'] = 'Anker Y pixel lokasjon';
$lang['apply'] = 'Bruk';
$lang['ask_delete_icon'] = 'Er du sikker p&aring; at vil fjerne dette ikonet fra listen (ingen filer vil bli slettet)';
$lang['ask_reset_icons'] = 'Er du sikker p&aring; at du vil fjerne alle ikoner, og tilbakestille til fabrikkstandard?';
$lang['baloon_maptemplate'] = 'Boble mal';
$lang['cancel'] = 'Avbryt';
$lang['category_template'] = 'Kategori visningsmal';
$lang['center_lat'] = 'Sentrer Breddegrad(Latitude)';
$lang['center_lon'] = 'Sentrer Lengdegrad(Longitude)';
$lang['clearcache'] = 'T&oslash;m det geografiske lokasjonsmellomlageret';
$lang['click'] = 'Klikk';
$lang['combine_points'] = 'Kombiner individuelle mark&oslash;rer som er innenfor rekkevidde';
$lang['combined_points_icon'] = 'Ikon &aring; benytte for kombinerte mark&oslash;rer';
$lang['controls'] = 'Kontroller';
$lang['controls_size'] = 'St&oslash;rrelse p&aring; kontroller';
$lang['default'] = 'Standard';
$lang['default_icon'] = 'Standard ikon';
$lang['default_templates'] = 'Standard maler';
$lang['delete'] = 'Slett';
$lang['delete_icon'] = 'Slett dette ikonet';
$lang['delete_map'] = 'Slett kart';
$lang['delete_map_point'] = 'Slett kart punkt';
$lang['description'] = 'Beskrivelse';
$lang['directions'] = 'Vis kj&oslash;reruter';
$lang['directions_dest'] = 'Hvor skal veibeskrivelse skrives';
$lang['directions_units'] = 'Kj&oslash;rerute enheter';
$lang['dirform_maptemplate'] = 'Kj&oslash;rerute skjemamal';
$lang['dropdown'] = 'Nedtrekk';
$lang['edit'] = 'Rediger';
$lang['edit_category'] = 'Rediger Mark&oslash;rkategori';
$lang['edit_icon'] = 'Rediger dette ikonet';
$lang['edit_map'] = 'Rediger kart';
$lang['edit_map_point'] = 'Rediger kartpunkt';
$lang['edit_map_points'] = 'Rediger kartpunkter';
$lang['edit_points_for_map'] = 'Rediger kartpunkter for kart &quot;%s&quot;';
$lang['error_browser_incompatible'] = 'Denne nettleseren klarer ikke &aring; vise kart fra google';
$lang['error_cannotdelete'] = 'Dette elementet kan ikke fjernes';
$lang['error_deletecategory'] = 'Problem med &aring; slette kategori';
$lang['error_invalidparams'] = 'En eller flere parametere mangler eller er ugyldige';
$lang['error_mapelem_notfound'] = 'Kartelement ikke funnet';
$lang['error_nameexists'] = 'Et element med dette navn eksisterer allerede';
$lang['error_noapikey'] = 'Google API Key er tom';
$lang['error_noapikey2'] = 'Google API-n&oslash;kkel er tom. Denne modulen vil ikke fungere skikkelig f&oslash;r det er satt et gyldig verdi levert av Google.';
$lang['error_notfound'] = 'Det forespurte elementet ble ikke funnet';
$lang['error_permissiondenied'] = 'Du har ikke de riktige rettigheter for &aring; utf&oslash;re denne handlingen';
$lang['friendlyname'] = 'Calguys Google Maps ';
$lang['from'] = 'Fra';
$lang['get_directions'] = 'Vis kj&oslash;rerute';
$lang['google_api_key'] = 'Google API Key ';
$lang['help'] = '<h3>What does this do</h3>
  <p>This module provides a quick, convenient, yet flexible and extendable way to place google maps on a page providing a number of built in functions, and providing easy extendability for those familiar with Javascript and the Google Maps API&#039;;
<h3>Features:</h3>
<ul>
  <li>Static map creation using a full admin interface for managing maps and markers within a map.</li>
  <li>Flexible marker icon management.</li>
  <li>The ability to categorize markers.  Markers can belong to more than one category.</li>
  <li>Infowindow content can be specified using HTML</li>
  <li>Streetview support</li>
  <li>The ability to display a sidebar of all markers associated with a map.</li>
  <li>The ability to display a category panel, and hide icons by unchecking a category checkbox.</li>
  <li>Directions support (either by displaying the route in the map (and with directions in a seperate panel), or by opening a new window</li>
  <li>Reads sensor information from GPS sensors on mobile devices.</li>
  <li>The ability to group markers that are within a lat/long radius to a single marker with a special icon.</li>
  <li>The ability to dynamically add markers given data from an outside point <em>(see {cggm_add_dynpoint})</em>
  <li>Uses jquery for advanced DOM manipulation.</li>
</ul>
<h3>How Do I Use It?</h3>
<ul>
<li>Install the module via the normal methods</li>
<li>Setup your users and groups with the appropriate permissions:
  <ul>
    <li>The &#039;Manage Maps&#039; Permission allows administrators to add/edit and delete maps</li>
    <li>The &#039;Manage Map Locations&#039; permission allows administrators to add/edit/delete points within a map</li>
  </ul>
</li>
<li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking.  Note that when resetting one of the map templates to defaults, you must still press the &amp;quot;Apply&amp;quot; or &amp;quot;Apply&amp;quot; buttons.</p>
<li>Mark one of your maps as default, by clicking on the red &#039;X&#039; beside a particular map.  This is useful if you don&#039;t specify the &#039;map&#039; parameter on the tag.</li>
<li>Create one or more points within the map, either by specifying a latitude and longitude, or with an address.</li>
<li>Add the {CGGoogleMaps} tag inside the content block of a page, or inside a page template.  Then you&#039;re finished.</li>
</ul>
<br/>
<h3>Adding Points to a Map Dynamically</h3>
<p>You can use smarty to add points to a module dynamically.  You can use this functionality to build a frappr like map with multiple points that are controlled dynamically from another module (like CompanyDirectory or FrontEndUsers).</p>
<h4>The {cggm_add_dynpoint} Smarty Plugin</h4>
<p>This smarty plugin <em>(only available when CGGoogleMaps is installed)</em> allows adding a point dynamically to a specified map.</p>
<h4>Usage:</h4>
<pre><code>{cggm_add_dynpoint map=1 name=&#039;New York&#039; address=&#039;New York, NY&#039; icon=&#039;food&#039;}</code></pre><br/>
<h4>Parameters:</h4>
  <ul> 
<li><strong>required</strong> - map : The (integer) ID of the map to add the point to</li>
<li><strong>required</strong> - name : The name of the point to add</li>
<li><em>optional</em> - desc/description : The HTML content to show in the info window</li>
<li><em>optional</em> - address : The address of the location you are adding. (you must specify an address, or lat and long parameters)</li>
<li><em>optional</em> - lat : The latitude of the location you are adding.</li>
<li><em>optional</em> - long : The longitude of the location you are adding.</li>
<li><em>optional</em> - category : A comma separated list of categories for this point (there is no need for the categories to already exists)</li>
<li><em>optional</em> - tooltip : A tooltip to display when hovering over a point.</li>
<li><em>optional</em> - icon : The name of an icon to use for this point.</li>
  </ul>
<br/>
<p><strong>Note:</strong> Either the lat and long parameters must be specified, or the address.</p>
<p><strong>Note:</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
</ul>
<h3>Upgrade Information:</h3>
<p><strong>Note:</strong> For people upgrading from CGGoogleMaps 1.x to the new 2.x series some work may need to be done, particularly if you have changed your map template, or are using custom options.  You may need to revise the styling of your map templates, and then update/save the values in the map settings.</p>
<p>Also: The sidebar_html, and sidebar_class parameters have been removed from the {cggm_add_dynpoint} smarty plugin.  This is due to the category functionality that has been added.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\&#039;s
module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Requirements</h3>
<p>This map functionality makes extensive use of <strong>JQuery</strong> it is your responsibility to include jquery in pages that use these maps and ensure that it is loaded before the map is called.  The easiest way to do this is by installing the JQueryTools module and adding {JQueryTools action=incjs} into the head portion of your page template.</p>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['height'] = 'H&oslash;yde';
$lang['help_anchor_location'] = '<strong>Merk:</strong>&nbsp;Anker lokasjoner spesifiserer pixel lokasjonen (relativ til &oslash;vre venstre hj&oslash;rne av bildet) hvor ikonet skal forankres til mark&oslash;ren. Om ingen verdi er spesifisert, vil senter p&aring; ikonet bli benyttet';
$lang['help_icon_url'] = 'Spesifiser URLen til det for-opplastede PNG-bildet. Dette bildet skal ikke v&aelig;re st&oslash;rre enn 32x32, og skal st&oslash;tte gjennomsiktighet. URLen kan vanligvis spesifiseres relativt til root p&aring; din installasjon';
$lang['help_param_defer'] = 'Angi at alle JavaScript-taggene skal ha utsette attributtsett. Dette kan v&aelig;re nyttig for problemer med IE7 og IE8 der Internet Explorer pr&oslash;ver &aring; kj&oslash;re javascript p&aring; en ufullstendig gjengitt side.';
$lang['help_param_map'] = 'Spesifiser IDen eller kartets navn som skal benyttes for &aring; legge ut google kartet. Om denne parameter ikke er spesifisert vil standard kart (om noe) bli benyttet.';
$lang['help_param_maptemplate'] = 'Spesifiser navnet p&aring; en eksisterende, ikke standard kartmal som skal benyttes for denne visningen. Om denne parameter ikke er spesifisert, vil n&aring;v&aelig;rende standard mal bli benyttet';
$lang['help_param_zoomlevel'] = '(integer) Tillater overstyring av zoom-niv&aring; lagret med kartet. Gyldige verdier er fra 1 til 17';
$lang['help_param_zoomencompass'] = '(boolean) Tillater overstyring av zoom omfang innstillingen som er lagret med kartet.';
$lang['hide_directions'] = 'Skjul kj&oslash;rerute';
$lang['horizontal_bar'] = 'Horisontal linjal';
$lang['hybrid'] = 'Hybrid ';
$lang['id'] = 'Id ';
$lang['icon'] = 'Ikon';
$lang['imperial'] = 'Britisk/Imperial';
$lang['info'] = 'Info ';
$lang['info_address_latlong'] = 'Merk: Oppgi <strong>enten</strong> en adresse <strong>eller</strong> en breddegrad(lattitude) og lengdegrad(longitude). Om begge er spesifisert vil bredegrad og lengdegrad bli gitt fortrinn.';
$lang['info_anchor_x'] = 'Infovindu anker X pixel lokasjon';
$lang['info_anchor_y'] = 'Infovindu anker Y pixel lokasjon';
$lang['info_bounds_fudge'] = 'N&aring;r zoom tilpasset er spesifisert s&aring; kan du spesifisere en prosent <em>(i desimal)</em> for hvor mye kartgrensene skal utvides for &aring; gi en marg omkring de omfattede punktene';
$lang['info_category_panel'] = 'Skal et panel vises som viser kategoriene for alle kartpunktene, og tillate &aring; sl&aring; kartmark&oslash;rer p&aring; og av etter kategori';
$lang['info_center_lat'] = 'Senter latitude er valgfri. Om spesifisert s&aring; vil det bli benyttet for &aring; sentrere kartet. Spesifiser en verdi i desimal grader f.eks.: -123.45';
$lang['info_center_lon'] = 'Senter longitude er valgfri. Om spesifisert s&aring; vil det bli benyttet for &aring; sentrere kartet. Spesifiser en verdi i desimal grader f.eks.: -123.45';
$lang['info_combine_points'] = 'Hvis valgt, vil mark&oslash;rene som er innenfor en angitt radius fra hverandre sl&aring;s sammen til en mark&oslash;r p&aring; kartet. Denne funksjonaliteten er nyttig hvis flere oppf&oslash;ringer eksisterer p&aring; samme (eller nesten de samme) koordinatene, for &aring; gj&oslash;re valget lettere. Denne funksjonaliteten er uavhengig av kartets zoom-niv&aring;.';
$lang['info_controls'] = 'Skal zoom og panorer kontroller vises?';
$lang['info_controls_size'] = 'Spesifiser st&oslash;rrelse p&aring; kontrollene p&aring; kartet';
$lang['info_default_icon'] = 'STandard ikonet blir benyttet n&aring;r ingen andre ikon er spesifisert for et kartpunkt';
$lang['info_directions'] = 'Tillat en bruker &aring; be om kj&oslash;rerute fra eller til et kartpunkt';
$lang['info_directions_dest'] = 'Spesifiser hvordan kj&oslash;rerutes skal behandles. Skal de vises i et nytt vindu, eller i kartpanelet';
$lang['info_directions_units'] = 'Spesifiser hvordan enhetene skal vises for kj&oslash;rerutene. Metrisk eller Britisk/imperial.';
$lang['info_height'] = 'Spesifiser en karth&oslash;yde (i pixler)';
$lang['info_icon_selection'] = 'Som standard, hvilket ikon skal v&aelig;re foretrukket for mark&oslash;rer n&aring;r et kategoripanel vises';
$lang['info_info_trigger'] = 'Angi hva som skal utl&oslash;se &aring;pningen av info-vinduet';
$lang['info_info_window'] = 'Skal informasjonsvinduet vises for hvert kartpunkt';
$lang['info_infowindow_height'] = 'Oppgi en h&oslash;yde (i pixler) for informasjonsvinduet';
$lang['info_infowindow_width'] = 'Oppgi en bredde (i pixler)for informasjonsvinduet';
$lang['info_map_type'] = 'Angi standard kartetype (hvis type kontroller er aktivert, kan brukeren endre typen etter at kartet vises)';
$lang['info_nav_control_opt'] = 'Spesifiser hva slags navigasjonskontroller for kartet';
$lang['info_point_combine_fudge'] = 'En mindre radius betyr at f&aelig;rre mark&oslash;rer blir satt sammen til en kartmark&oslash;r. Negative verdier er ugyldige.';
$lang['info_point_combine_icon'] = 'Spesifiser et ikon &aring; benytte for &aring; illustrere p&aring; kartet at mark&oslash;ren best&aring;r av flere punkter som er innenfor et lite omr&aring;de';
$lang['info_scalecontrols'] = 'En skalerer kan valgfritt vises i nedre h&oslash;yre hj&oslash;rne p&aring; kartet';
$lang['info_sensor'] = 'Noen nettlesere (spesielt mobile nettlesere) er i stand til &aring; gi bredde- og lengdegrad. Vil du aktivere dette?';
$lang['info_sidebar'] = 'Skal et sidepanel inneholdende alle kartpunkter vises?';
$lang['info_sv_controls'] = 'Skal Gatevisningskontroller vises p&aring; kartet?';
$lang['info_sv_radius'] = 'N&aring;r Streetview er p&aring;sl&aring;tt for en mark&oslash;r, hvor langt bort (i meter) skal den s&oslash;ke etter en gyldig streetview plassering.  Dette er viktig i i mer lettbebygde str&oslash;k hvor StreetView ikke n&oslash;dvendigvis har g&aring;tt gjennom hver gate.';
$lang['info_sysdflt_baloon_template'] = 'Systemstandard &quot;Boble&quot; mal';
$lang['info_sysdflt_category_template'] = 'Systemstandard &quot;Kategoriliste&quot; mal';
$lang['info_sysdflt_dirform_template'] = 'Systemstandard &quot;Kj&oslash;reruteskjema&quot; mal';
$lang['info_sysdflt_js_template'] = 'Systemstandard javascriptmal';
$lang['info_sysdflt_map_template'] = 'Systemstandard kartmal';
$lang['info_sysdflt_sidebar_template'] = 'Systemstandard sidepanelmal';
$lang['info_sysdflt_template'] = 'Dette skjema tilbyr mulighet til &aring; spesifisere innholdet som vil bli vist n&aring;r du oppretter en ny mal av denne typen. &Aring; redigere i dette skjema vil ikke ha umiddelbar effekt p&aring; ditt nettsted';
$lang['info_type_control_opt'] = 'Spesifiser hvordan karttypekontrolleren skal vises';
$lang['info_width'] = 'Spesifiser en kartbredde (i pixler)';
$lang['infowindow_width'] = 'Bredde p&aring; InfoVindu';
$lang['infowindow_height'] = 'H&oslash;yde p&aring; InfoVindu';
$lang['info_type_controls'] = 'Tillat brukeren &aring; endre karttypen?';
$lang['info_zoom'] = 'Spesifiser et innledende zoomniv&aring; (merk at denne parameteren ikke er gyldig &quot;zoom tilpasset&quot; er benyttet';
$lang['info_zoom_encompass'] = 'Skal zoomniv&aring;et p&aring; kartet tilpasses alle punktene?';
$lang['js_template'] = 'Javascriptmal';
$lang['large'] = 'Stort';
$lang['latitude'] = 'Bredegrad(Latitude)';
$lang['latlong'] = 'Breddegrad / Lengdegrad';
$lang['location'] = 'Sted';
$lang['longitude'] = 'Lengdegrad(Longitude)';
$lang['make_default'] = 'gj&oslash;r dette ikonet til standard ikon';
$lang['marker_categories'] = 'Mark&oslash;r kategorier';
$lang['marker_icons'] = 'Mark&oslash;rikoner';
$lang['marker_skipped'] = 'Geografisk plassering (adresse til lat/long) mislyktes .. marker &quot;%s&quot; som hoppet over';
$lang['map'] = 'Kart';
$lang['maps'] = 'Kart';
$lang['maptemplate_addedit'] = 'Legg til/rediger kartmal';
$lang['map_name'] = 'Kartnavn';
$lang['map_template'] = 'Kartmal';
$lang['map_templates'] = 'Kartmaler';
$lang['map_type'] = 'Karttype';
$lang['metric'] = 'Metrisk';
$lang['moddescription'] = 'En enkel modul for &aring; lage google kart';
$lang['mouseover'] = 'MouseOver ';
$lang['msg_addresscache_cleared'] = 'Geografisk lokasjonslager t&oslash;mt';
$lang['msg_categoryadded'] = 'Kategori lagt til';
$lang['msg_categorydeleted'] = 'Kategori slettet';
$lang['msg_categoryupdated'] = 'Kategori oppdatert';
$lang['msg_default_icon_uchanged'] = 'Standardikonet har blitt endret';
$lang['msg_icons_reset'] = 'Ikoner har blitt tilbakestilt til fabrikk standard innstillinger';
$lang['msg_icon_removed'] = 'Ikon fjernet fra databasen  Ingen filer ble slettet';
$lang['msg_icon_updated'] = 'Ikoninformasjon endret';
$lang['name'] = 'Navn';
$lang['nav_control_opt'] = 'Navigasjon kontrollst&oslash;rrelse';
$lang['none'] = 'Ingen';
$lang['panel'] = 'Panel ';
$lang['points'] = 'Punkter';
$lang['point_combine_fudge'] = 'Spesifiser en radius som avgj&oslash;r hvilke punkter som skal kombineres.';
$lang['point_combine_icon'] = 'Kombinerte punkter ikon';
$lang['point_name'] = 'Punkt navn';
$lang['point_type'] = 'Punkt type';
$lang['policy_cachefirst'] = 'Les cache f&oslash;r oppslag av adresse online';
$lang['policy_cacheonly'] = 'Benytt alltid cache';
$lang['policy_nocache'] = 'Benytt aldri cache (kun benytt online oppslag)';
$lang['postinstall'] = 'CGGoogleMaps modulen har blitt installert';
$lang['postuninstall'] = 'CGGoogleMaps modulen og alle relevante data har blitt fjernet';
$lang['preferences'] = 'Innstillinger';
$lang['prompt_bounds_fudge'] = 'Zoom tilpasset margavstand';
$lang['prompt_categories'] = 'Kategorier';
$lang['prompt_directions'] = 'Kj&oslash;rerute';
$lang['prompt_from_here'] = 'Fra her';
$lang['prompt_icon_selection'] = 'Ikonvalg';
$lang['prompt_info_window'] = 'Vis infovindu';
$lang['prompt_info_trigger'] = 'Infovindu trigger';
$lang['prompt_lookup_policy'] = 'Oppslagspolitikk';
$lang['prompt_lookup_service'] = 'Oppslagservice';
$lang['prompt_to_here'] = 'Til hit';
$lang['prompt_sensor'] = 'Lever geografisk lokasjonsinformasjon til kartet';
$lang['prompt_zoom'] = 'Zoom-niv&aring;';
$lang['really_uninstall'] = 'Er du virkelig sikker p&aring; du vil avinstallere denne modulen?';
$lang['reset'] = 'Nullstill';
$lang['reset_icons'] = 'Tilbakestill ikoner';
$lang['satellite'] = 'Satelitt';
$lang['scalecontrols'] = 'Vis skalering';
$lang['set_dflt_map'] = 'Sett kartet som standard';
$lang['show_category_panel'] = 'Vis kategoripanelet';
$lang['sidebar'] = 'Vis sidestolpe';
$lang['sidebar_template'] = 'Sidestolpe mal';
$lang['small'] = 'Liten';
$lang['submit'] = 'Lagre';
$lang['sv_controls'] = 'Vis gatevisningskontroller';
$lang['sv_radius'] = 'Streetview s&oslash;keradius';
$lang['tab_advanced'] = 'Avansert';
$lang['tab_directions'] = 'Kj&oslash;rerute';
$lang['tab_jstemplate'] = 'Javascriptmal';
$lang['tab_settings'] = 'Innstillinger';
$lang['tab_maptemplate'] = 'Kartmal';
$lang['text'] = 'Tekst';
$lang['to'] = 'Til';
$lang['type'] = 'Type ';
$lang['type_controls'] = 'Vis skrive kontroller';
$lang['type_control_opt'] = 'Skrivekontroll valg';
$lang['url'] = 'URL ';
$lang['use_category_icon'] = 'Foretrekk kategori-ikonet';
$lang['use_marker_icon'] = 'Foretrekk mark&oslash;rikonet';
$lang['width'] = 'Bredde';
$lang['window'] = 'Vindu';
$lang['zoom_encompass'] = 'Zoom tilpasset';
$lang['qca'] = 'P0-536849115-1307983495210';
$lang['utma'] = '156861353.1633959484.1322167008.1322178860.1322242091.3';
$lang['utmz'] = '156861353.1322167008.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1322242091';
?>